@@ -2,32 +2,40 @@ package Net::Whois::Object::AutNum;
 
 use base qw/Net::Whois::Object/;
 
-# http://www.ripe.net/data-tools/support/documentation/update-ref-manual#section-9
-# http://www.apnic.net/apnic-info/whois_search/using-whois/guide/aut-num
-#
-# aut-num:       [mandatory]  [single]     [primary/look-up key]
-# as-name:       [mandatory]  [single]     [ ]
-# descr:         [mandatory]  [multiple]   [ ]
-# member-of:     [optional]   [multiple]   [inverse key]
-# import:        [optional]   [multiple]   [ ]
-# mp-import:     [optional]   [multiple]   [ ]
-# export:        [optional]   [multiple]   [ ]
-# mp-export:     [optional]   [multiple]   [ ]
-# default:       [optional]   [multiple]   [ ]
-# mp-default:    [optional]   [multiple]   [ ]
-# remarks:       [optional]   [multiple]   [ ]
-# admin-c:       [mandatory]  [multiple]   [inverse key]
-# tech-c:        [mandatory]  [multiple]   [inverse key]
-# notify:        [optional]   [multiple]   [inverse key]
-# mnt-lower:     [optional]   [multiple]   [inverse key]
-# mnt-routes:    [optional]   [multiple]   [inverse key]
-# mnt-by:        [mandatory]  [multiple]   [inverse key]
-# changed:       [mandatory]  [multiple]   [ ]
-# source:        [mandatory]  [single]     [ ]
+# from : whois -t aut-num
+# % This is the RIPE Database query service.
+# % The objects are in RPSL format.
+# %
+# % The RIPE Database is subject to Terms and Conditions.
+# % See http://www.ripe.net/db/support/db-terms-conditions.pdf
+# 
+# aut-num:        [mandatory]  [single]     [primary/lookup key]
+# as-name:        [mandatory]  [single]     [ ]
+# descr:          [mandatory]  [multiple]   [ ]
+# member-of:      [optional]   [multiple]   [inverse key]
+# import:         [optional]   [multiple]   [ ]
+# mp-import:      [optional]   [multiple]   [ ]
+# export:         [optional]   [multiple]   [ ]
+# mp-export:      [optional]   [multiple]   [ ]
+# default:        [optional]   [multiple]   [ ]
+# mp-default:     [optional]   [multiple]   [ ]
+# remarks:        [optional]   [multiple]   [ ]
+# org:            [optional]   [single]     [inverse key]
+# admin-c:        [mandatory]  [multiple]   [inverse key]
+# tech-c:         [mandatory]  [multiple]   [inverse key]
+# notify:         [optional]   [multiple]   [inverse key]
+# mnt-lower:      [optional]   [multiple]   [inverse key]
+# mnt-routes:     [optional]   [multiple]   [inverse key]
+# mnt-by:         [mandatory]  [multiple]   [inverse key]
+# changed:        [mandatory]  [multiple]   [ ]
+# source:         [mandatory]  [single]     [ ]
+# 
+# % This query was served by the RIPE Database Query Service version 1.38 (WHOIS1)
+
 __PACKAGE__->attributes( 'primary',   ['aut_num'] );
 __PACKAGE__->attributes( 'mandatory', [ 'aut_num', 'as_name', 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'source' ] );
-__PACKAGE__->attributes( 'optional', [ 'member_of', 'import', 'mp_import', 'export', 'mp_export', 'default', 'mp_default', 'remarks', 'notify', 'mnt_lower', 'mnt_routes', 'org' ] );
-__PACKAGE__->attributes( 'single', [ 'aut_num', 'as_name', 'source', 'org' ] );
+__PACKAGE__->attributes( 'optional', [ 'member_of', 'import', 'mp_import', 'export', 'mp_export', 'default', 'mp_default', 'remarks', 'org', 'notify', 'mnt_lower', 'mnt_routes'  ] );
+__PACKAGE__->attributes( 'single', [ 'aut_num', 'as_name', 'org', 'source' ] );
 __PACKAGE__->attributes( 'multiple', [ 'descr', 'member_of', 'import', 'mp_import', 'export', 'mp_export', 'default', 'mp_default', 'remarks', 'admin_c', 'tech_c', 'notify', 'mnt_lower', 'mnt_routes', 'mnt_by', 'changed' ] );
 
 
