@@ -2,6 +2,10 @@ package Net::Whois::Object::Information;
 
 use base qw/Net::Whois::Object/;
 
+__PACKAGE__->attributes( 'mandatory', ['comment'] );
+__PACKAGE__->attributes( 'optional', [] );
+__PACKAGE__->attributes( 'multiple',  ['comment'] );
+
 =head1 NAME
 
 Net::Whois::Object::Information - an object representation of the RPSL Information block
@@ -33,10 +37,6 @@ sub new {
     my $self = bless {}, $class;
     $self->_init(@options);
 
-    $self->attributes( 'mandatory', ['comment'] );
-    $self->attributes( 'optional', [] );
-    $self->attributes( 'multiple',  ['comment'] );
-
     return $self;
 }
 
@@ -48,10 +48,4 @@ always return the current comment array.
 
 =cut
 
-sub comment {
-    my ( $self, $comment ) = @_;
-
-    return $self->_multiple_attribute_setget( 'comment', $comment );
-}
-
 1;
